@@ -225,6 +225,11 @@ run (void *cls,
              GNUNET_i2s_full (&my_full_id));
   if (show_conns || monitor_connections)
   {
+    if (monitor_connections)
+    {
+      fprintf (stdout,
+               _ ("Monitoring connections. Press CTRL-C to quit.\n\n"));
+    }
     mh = GNUNET_CORE_monitor_start (cfg, &monitor_cb, NULL);
     if (NULL == mh)
     {
@@ -271,8 +276,6 @@ main (int argc, char *const *argv)
       &show_conns),
     GNUNET_GETOPT_OPTION_END };
 
-  if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
-    return 2;
   res = GNUNET_PROGRAM_run (argc,
                             argv,
                             "gnunet-core",
@@ -282,7 +285,6 @@ main (int argc, char *const *argv)
                             &run,
                             NULL);
 
-  GNUNET_free_nz ((void *) argv);
   if (GNUNET_OK == res)
     return ret;
   return 1;
