@@ -989,8 +989,6 @@ main (int argc, char *const *argv)
   bo.expiration_time =
     GNUNET_TIME_year_to_time (GNUNET_TIME_get_current_year () + 2);
 
-  if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
-    return 2;
   ret =
     (GNUNET_OK ==
      GNUNET_PROGRAM_run (argc,
@@ -1002,7 +1000,6 @@ main (int argc, char *const *argv)
                          NULL))
     ? ret
     : 1;
-  GNUNET_free_nz ((void *) argv);
   return ret;
 }
 
