@@ -797,9 +797,6 @@ main (int argc, char *const *argv)
       &verbose),
     GNUNET_GETOPT_OPTION_END };
 
-  if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
-    return 12;
-
   if (GNUNET_SYSERR ==
       GNUNET_PROGRAM_run (argc,
                           argv,
@@ -811,7 +808,6 @@ main (int argc, char *const *argv)
                           NULL))
     ret = 1;
 
-  GNUNET_free_nz ((void *) argv);
   return ret;
 }
 
