@@ -427,8 +427,6 @@ main (int argc, char *const *argv)
                                &print_hellos),    GNUNET_GETOPT_OPTION_END
   };
 
-  if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
-    return 2;
   res = GNUNET_PROGRAM_run (argc,
                             argv,
                             "gnunet-hello",
@@ -438,7 +436,6 @@ main (int argc, char *const *argv)
                             &run,
                             NULL);
 
-  GNUNET_free_nz ((void *) argv);
   if (GNUNET_OK == res)
     return ret;
   return 1;
