@@ -615,10 +615,6 @@ main (int argc, char *const *argv)
   };
   int res;
 
-  if (GNUNET_OK !=
-      GNUNET_STRINGS_get_utf8_args (argc, argv,
-                                    &argc, &argv))
-    return 4;
   global_ret = TIMEOUT_STATUS_CODE; /* timeout */
   res = GNUNET_PROGRAM_run (argc,
                             argv,
@@ -627,7 +623,6 @@ main (int argc, char *const *argv)
                             options,
                             &run,
                             NULL);
-  GNUNET_free_nz ((void *) argv);
 
   if (GNUNET_OK != res)
     return 3;
