@@ -2070,7 +2070,7 @@ id_connect_cb (void *cls,
     GNUNET_CONTAINER_DLL_insert_tail (ego_head,
                                       ego_tail,
                                       ego_entry);
-    if ((NULL != ego_name_tmp) &&
+    if ((NULL != ego_name) && (NULL != ego_name_tmp) &&
         (0 == strcmp (ego_name, ego_name_tmp)))
       zone_pkey = *GNUNET_IDENTITY_ego_get_private_key (ego);
     return;
@@ -2259,9 +2259,6 @@ main (int argc, char *const *argv)
     GNUNET_GETOPT_OPTION_END };
 
 
-  if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
-    return 2;
-
   is_public = -1;
   is_shadow = -1;
   is_maintenance = -1;
@@ -2275,12 +2272,10 @@ main (int argc, char *const *argv)
                                   &run,
                                   NULL)))
   {
-    GNUNET_free_nz ((void *) argv);
     // FIXME
     // GNUNET_CRYPTO_ecdsa_key_clear (&zone_pkey);
     return lret;
   }
-  GNUNET_free_nz ((void *) argv);
   // FIXME
   // GNUNET_CRYPTO_ecdsa_key_clear (&zone_pkey);
   return ret;
