@@ -1093,9 +1093,6 @@ main (int argc, char *const *argv)
 
 
   timeout = GNUNET_TIME_UNIT_FOREVER_REL;
-  if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
-    return 2;
-
   GNUNET_log_setup ("gnunet-abd", "WARNING", NULL);
   if (GNUNET_OK != GNUNET_PROGRAM_run (argc,
                                        argv,
@@ -1105,7 +1102,6 @@ main (int argc, char *const *argv)
                                        &run,
                                        NULL))
     ret = 1;
-  GNUNET_free_nz ((void *) argv);
   return ret;
 }
 
