@@ -331,29 +331,6 @@ struct GNUNET_MessageHeader
 };
 
 
-/**
- * Answer from service to client about last operation.
- */
-struct GNUNET_OperationResultMessage
-{
-  struct GNUNET_MessageHeader header;
-
-  uint32_t reserved GNUNET_PACKED;
-
-  /**
-   * Operation ID.
-   */
-  uint64_t op_id GNUNET_PACKED;
-
-  /**
-   * Status code for the operation.
-   */
-  uint64_t result_code GNUNET_PACKED;
-
-  /* Followed by data. */
-};
-
-
 /**
  * Identifier for an asynchronous execution context.
  */
@@ -1362,32 +1339,6 @@ GNUNET_is_zero_ (const void *a,
   })
 /* *INDENT-ON* */
 
-/**
- * @ingroup memory
- * Allocate a size @a n times @a m array
- * with structs or unions of the given @a type.
- *
- * @param n size of the first dimension
- * @param m size of the second dimension
- * @param type name of the struct or union, i.e. pass 'struct Foo'.
- */
-#define GNUNET_new_array_2d(n, m, type) \
-        (type **) GNUNET_xnew_array_2d_ (n, m, sizeof(type), __FILE__, __LINE__)
-
-/**
- * @ingroup memory
- * Allocate a size @a n times @a m times @a o array
- * with structs or unions of the given @a type.
- *
- * @param n size of the first dimension
- * @param m size of the second dimension
- * @param o size of the third dimension
- * @param type name of the struct or union, i.e. pass 'struct Foo'.
- */
-#define GNUNET_new_array_3d(n, m, o, type) \
-        (type ***) GNUNET_xnew_array_3d_ (n, m, o, sizeof(type), __FILE__, \
-                                          __LINE__)
-
 /**
  * @ingroup memory
  * Wrapper around malloc. Allocates size bytes of memory.
@@ -1639,52 +1590,6 @@ GNUNET_xmalloc_ (size_t size,
                  int linenumber);
 
 
-/**
- * Allocate memory for a two dimensional array in one block
- * and set up pointers. Aborts if no more memory is available.
- * Don't use GNUNET_xnew_array_2d_ directly. Use the
- * #GNUNET_new_array_2d macro.
- * The memory of the elements will be zero'ed out.
- *
- * @param n size of the first dimension
- * @param m size of the second dimension
- * @param elementSize size of a single element in bytes
- * @param filename where is this call being made (for debugging)
- * @param linenumber line where this call is being made (for debugging)
- * @return allocated memory, never NULL
- */
-void **
-GNUNET_xnew_array_2d_ (size_t n,
-                       size_t m,
-                       size_t elementSize,
-                       const char *filename,
-                       int linenumber);
-
-
-/**
- * Allocate memory for a three dimensional array in one block
- * and set up pointers. Aborts if no more memory is available.
- * Don't use GNUNET_xnew_array_3d_ directly. Use the
- * #GNUNET_new_array_3d macro.
- * The memory of the elements will be zero'ed out.
- *
- * @param n size of the first dimension
- * @param m size of the second dimension
- * @param o size of the third dimension
- * @param elementSize size of a single element in bytes
- * @param filename where is this call being made (for debugging)
- * @param linenumber line where this call is being made (for debugging)
- * @return allocated memory, never NULL
- */
-void ***
-GNUNET_xnew_array_3d_ (size_t n,
-                       size_t m,
-                       size_t o,
-                       size_t elementSize,
-                       const char *filename,
-                       int linenumber);
-
-
 /**
  * Allocate and initialize memory. Checks the return value, aborts if no more
  * memory is available.  Don't use GNUNET_xmemdup_ directly. Use the
