@@ -61,6 +61,7 @@ extern "C"
 #endif
 #endif
 
+
 #include "gnunet_util_lib.h"
 #include "gnunet_identity_service.h"
 #include "gnunet_namestore_service.h"
@@ -150,7 +151,7 @@ typedef void
                                          struct GNUNET_CONVERSATION_Caller *
                                          caller,
                                          const struct
-                                         GNUNET_IDENTITY_PublicKey *caller_id);
+                                         GNUNET_CRYPTO_PublicKey *caller_id);
 
 
 /**
