@@ -38,10 +38,14 @@
  * @{
  */
 
+#if ! defined (__GNUNET_UTIL_LIB_H_INSIDE__)
+#error "Only <gnunet_util_lib.h> can be included directly."
+#endif
+
 #ifndef GNUNET_HELPER_LIB_H
 #define GNUNET_HELPER_LIB_H
 
-#include "gnunet_scheduler_lib.h"
+
 #include "gnunet_mst_lib.h"
 
 
@@ -95,8 +99,9 @@ GNUNET_HELPER_start (int with_control_pipe,
  *          stdin; #GNUNET_NO to signal termination by sending SIGTERM to helper
  * @return #GNUNET_OK on success; #GNUNET_SYSERR on error
  */
-int
-GNUNET_HELPER_kill (struct GNUNET_HELPER_Handle *h, int soft_kill);
+enum GNUNET_GenericReturnValue
+GNUNET_HELPER_kill (struct GNUNET_HELPER_Handle *h,
+                    int soft_kill);
 
 
 /**
@@ -107,7 +112,7 @@ GNUNET_HELPER_kill (struct GNUNET_HELPER_Handle *h, int soft_kill);
  * @param h the helper handle
  * @return #GNUNET_OK on success; #GNUNET_SYSERR on error
  */
-int
+enum GNUNET_GenericReturnValue
 GNUNET_HELPER_wait (struct GNUNET_HELPER_Handle *h);
 
 
@@ -140,8 +145,10 @@ GNUNET_HELPER_stop (struct GNUNET_HELPER_Handle *h, int soft_kill);
  *               #GNUNET_NO if helper process died
  *               #GNUNET_SYSERR during GNUNET_HELPER_destroy
  */
-typedef void (*GNUNET_HELPER_Continuation)(void *cls,
-                                           int result);
+typedef void
+(*GNUNET_HELPER_Continuation)(
+  void *cls,
+  enum GNUNET_GenericReturnValue result);
 
 
 /**
@@ -166,7 +173,7 @@ struct GNUNET_HELPER_SendHandle;
 struct GNUNET_HELPER_SendHandle *
 GNUNET_HELPER_send (struct GNUNET_HELPER_Handle *h,
                     const struct GNUNET_MessageHeader *msg,
-                    int can_drop,
+                    bool can_drop,
                     GNUNET_HELPER_Continuation cont,
                     void *cont_cls);
 
