@@ -226,7 +226,7 @@ enum GNUNET_MESSENGER_MessageKind
   GNUNET_MESSENGER_KIND_UNKNOWN = 0
 };
 
-#define GNUNET_MESSENGER_KIND_MAX (GNUNET_MESSENGER_KIND_DELETE)
+#define GNUNET_MESSENGER_KIND_MAX (GNUNET_MESSENGER_KIND_TALK)
 
 /**
  * Get the name of a message <i>kind</i>.
