@@ -34,6 +34,7 @@
 #ifndef GNUNET_NAMESTORE_PLUGIN_H
 #define GNUNET_NAMESTORE_PLUGIN_H
 
+
 #include "gnunet_util_lib.h"
 #include "gnunet_namestore_service.h"
 
@@ -52,6 +53,7 @@ extern "C"
  * @param cls closure
  * @param serial unique serial number of the record, MUST NOT BE ZERO,
  *               and must be monotonically increasing while iterating
+ * @param editor_hint content of the editor field when record was read (may be NULL)
  * @param zone_key private key of the zone
  * @param label name that is being mapped (at most 255 characters long)
  * @param rd_count number of entries in @a rd array
@@ -60,8 +62,9 @@ extern "C"
 typedef void
 (*GNUNET_NAMESTORE_RecordIterator) (void *cls,
                                     uint64_t serial,
+                                    const char *editor_hint,
                                     const struct
-                                    GNUNET_IDENTITY_PrivateKey *private_key,
+                                    GNUNET_CRYPTO_PrivateKey *private_key,
                                     const char *label,
                                     unsigned int rd_count,
                                     const struct GNUNET_GNSRECORD_Data *rd);
@@ -88,12 +91,12 @@ struct GNUNET_NAMESTORE_PluginFunctions
    * @param rd array of records with data to store
    * @return #GNUNET_OK on success, else #GNUNET_SYSERR
    */
-  int
-  (*store_records) (void *cls,
-                    const struct GNUNET_IDENTITY_PrivateKey *zone,
-                    const char *label,
-                    unsigned int rd_count,
-                    const struct GNUNET_GNSRECORD_Data *rd);
+  enum GNUNET_GenericReturnValue
+  (*store_records)(void *cls,
+                   const struct GNUNET_CRYPTO_PrivateKey *zone,
+                   const char *label,
+                   unsigned int rd_count,
+                   const struct GNUNET_GNSRECORD_Data *rd);
 
   /**
    * Lookup records in the datastore for which we are the authority.
@@ -105,12 +108,12 @@ struct GNUNET_NAMESTORE_PluginFunctions
    * @param iter_cls closure for @a iter
    * @return #GNUNET_OK on success, #GNUNET_NO for no results, else #GNUNET_SYSERR
    */
-  int
-  (*lookup_records) (void *cls,
-                     const struct GNUNET_IDENTITY_PrivateKey *zone,
-                     const char *label,
-                     GNUNET_NAMESTORE_RecordIterator iter,
-                     void *iter_cls);
+  enum GNUNET_GenericReturnValue
+  (*lookup_records)(void *cls,
+                    const struct GNUNET_CRYPTO_PrivateKey *zone,
+                    const char *label,
+                    GNUNET_NAMESTORE_RecordIterator iter,
+                    void *iter_cls);
 
 
   /**
@@ -127,13 +130,13 @@ struct GNUNET_NAMESTORE_PluginFunctions
    * @param iter_cls closure for @a iter
    * @return #GNUNET_OK on success, #GNUNET_NO if there were no more results, #GNUNET_SYSERR on error
    */
-  int
-  (*iterate_records) (void *cls,
-                      const struct GNUNET_IDENTITY_PrivateKey *zone,
-                      uint64_t serial,
-                      uint64_t limit,
-                      GNUNET_NAMESTORE_RecordIterator iter,
-                      void *iter_cls);
+  enum GNUNET_GenericReturnValue
+  (*iterate_records)(void *cls,
+                     const struct GNUNET_CRYPTO_PrivateKey *zone,
+                     uint64_t serial,
+                     uint64_t limit,
+                     GNUNET_NAMESTORE_RecordIterator iter,
+                     void *iter_cls);
 
 
   /**
@@ -147,86 +150,110 @@ struct GNUNET_NAMESTORE_PluginFunctions
    * @param iter_cls closure for @a iter
    * @return #GNUNET_OK on success, #GNUNET_NO if there were no results, #GNUNET_SYSERR on error
    */
-  int
-  (*zone_to_name) (void *cls,
-                   const struct GNUNET_IDENTITY_PrivateKey *zone,
-                   const struct GNUNET_IDENTITY_PublicKey *value_zone,
-                   GNUNET_NAMESTORE_RecordIterator iter,
-                   void *iter_cls);
+  enum GNUNET_GenericReturnValue
+  (*zone_to_name)(void *cls,
+                  const struct GNUNET_CRYPTO_PrivateKey *zone,
+                  const struct GNUNET_CRYPTO_PublicKey *value_zone,
+                  GNUNET_NAMESTORE_RecordIterator iter,
+                  void *iter_cls);
 
   /** Transaction-based API draft **/
 
   /**
-   * Start a transaction in the database
-   *
-   * @param cls closure (internal context for the plugin)
-   * @param emsg message. On error, string will be allocated and must be freed.
-   * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
-   */
-  enum GNUNET_GenericReturnValue
-  (*transaction_begin) (void *cls, char **emsg);
-
-  /**
-   * Abort and roll back a transaction in the database
-   *
-   * @param cls closure (internal context for the plugin)
-   * @param emsg message. On error, string will be allocated and must be freed.
-   * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
-   */
-  enum GNUNET_GenericReturnValue
-  (*transaction_rollback) (void *cls, char **emsg);
-
-  /**
-   * Commit a transaction in the database
-   *
-   * @param cls closure (internal context for the plugin)
-   * @param emsg message. On error, string will be allocated and must be freed.
-   * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
-   */
-  enum GNUNET_GenericReturnValue
-  (*transaction_commit) (void *cls, char **emsg);
-
-  /**
-   * Edit records in the datastore for which we are the authority.
-   * Should be called within a transaction (after begin) and maps
-   * to a SELECT ... FOR UPDATE in PQ.
+   * Edit records in the namestore.
+   * This modifies the editor hint, an advisory lock entry.
+   * The record iterator will be called with the old editor hint (if any).
    *
    * @param cls closure (internal context for the plugin)
    * @param zone private key of the zone
+   * @param editor_hint the new value for the advisory lock field
    * @param label name of the record in the zone
    * @param iter function to call with the result
    * @param iter_cls closure for @a iter
    * @return #GNUNET_OK on success, #GNUNET_NO for no results, else #GNUNET_SYSERR
    */
-  int
-  (*edit_records) (void *cls,
-                     const struct GNUNET_IDENTITY_PrivateKey *zone,
-                     const char *label,
-                     GNUNET_NAMESTORE_RecordIterator iter,
-                     void *iter_cls);
+  enum GNUNET_GenericReturnValue
+  (*edit_records)(void *cls,
+                  const char *editor_hint,
+                  const struct GNUNET_CRYPTO_PrivateKey *zone,
+                  const char *label,
+                  GNUNET_NAMESTORE_RecordIterator iter,
+                  void *iter_cls);
+
+  /**
+   * This clears the editor hint, unless it does not match the
+   * given editor hint, in which case this is a NOP.
+   * If a replacement hint is given, it hint is not cleared, but
+   * set to the replacement.
+   *
+   * @param cls closure (internal context for the plugin)
+   * @param zone private key of the zone
+   * @param editor_hint the new value for the advisory lock field
+   * @param editor_hint_replacement an optional value to use instead of a clear
+   * @param label name of the record in the zone
+   * @param iter function to call with the result
+   * @param iter_cls closure for @a iter
+   * @return #GNUNET_OK on success, #GNUNET_NO for no results, else #GNUNET_SYSERR
+   */
+  enum GNUNET_GenericReturnValue
+  (*clear_editor_hint)(void *cls,
+                  const char *editor_hint,
+                  const char *editor_hint_replacement,
+                  const struct GNUNET_CRYPTO_PrivateKey *zone,
+                       const char *label);
+
+  /**
+   * Tell plugin that a set of procedures are coming that
+   * are ideally handled within a single TX (BEGIN/COMMIT).
+   * This may be implemented as a NOP, but can speed up
+   * store calls in some cases (e.g. SQL databases)
+   *
+   * @param cls closure (internal context for the plugin)
+   * @return #GNUNET_OK on success, else fails with #GNUNET_SYSERR
+   */
+  enum GNUNET_GenericReturnValue
+  (*begin_tx)(void *cls);
+
+  /**
+   * Tell plugin the we finished what we started with
+   * #begin_tx
+   *
+   * @param cls closure (internal context for the plugin)
+   * @return #GNUNET_OK on success, else fails with #GNUNET_SYSERR
+   */
+  enum GNUNET_GenericReturnValue
+  (*commit_tx)(void *cls);
+
+  /**
+   * Tell plugin to rollback what we started with
+   * #begin_tx
+   * This may be a NOP (and thus NOT roll anything back!)
+   *
+   * @param cls closure (internal context for the plugin)
+   * @return #GNUNET_OK on success, else fails with #GNUNET_SYSERR
+   */
+  enum GNUNET_GenericReturnValue
+  (*rollback_tx)(void *cls);
 
   /**
    * Setup the database.
-   * Note that this will also fail if the database is already initialized.
-   * See reset_database().
    *
    * @param cls closure (internal context for the plugin)
-   * @param emsg error message on failure. Will be allocated, must be freed.
    * @return #GNUNET_OK on success, else fails with #GNUNET_SYSERR
    */
-  int
-  (*initialize_database) (void *cls, char **emsg);
+  enum GNUNET_GenericReturnValue
+  (*create_tables)(void *cls);
+
 
   /**
-   * Re-initializes the database.
-   * DANGEROUS: All existing data in the dabase will be lost!
+   * Drop existing tables.
+   * DANGEROUS: All existing data in the database will be lost!
    *
    * @param cls closure (internal context for the plugin)
-   * @param emsg error message on failure. Will be allocated, must be freed.
    * @return #GNUNET_OK on success, else fails with #GNUNET_SYSERR
    */
-  int
-  (*reset_database) (void *cls, char **emsg);
+  enum GNUNET_GenericReturnValue
+  (*drop_tables)(void *cls);
 };
 
 
