@@ -99,7 +99,7 @@ static char *plugin_name;
 /**
  * The loaded topology.
  */
-  struct GNUNET_TESTING_NetjailTopology *njt;
+struct GNUNET_TESTING_NetjailTopology *njt;
 
 /**
  * Our message stream tokenizer
@@ -144,7 +144,7 @@ static bool finished;
  * @param cls NULL
  */
 static void
-do_shutdown (void *cls)
+do_shutdown_later (void *cls)
 {
   struct WriteContext *wc;
 
@@ -175,6 +175,7 @@ do_shutdown (void *cls)
   {
     GNUNET_PLUGIN_unload (plugin_name,
                           plugin);
+    plugin = NULL;
   }
   if (NULL != njt)
   {
@@ -184,6 +185,20 @@ do_shutdown (void *cls)
 }
 
 
+/**
+ * Task to shut down cleanly
+ *
+ * @param cls NULL
+ */
+static void
+do_shutdown (void *cls)
+{
+  GNUNET_SCHEDULER_add_with_priority (GNUNET_SCHEDULER_PRIORITY_IDLE,
+                                      &do_shutdown_later,
+                                      NULL);
+}
+
+
 /**
  * Task to write to the standard out
  *
@@ -312,7 +327,7 @@ handle_helper_init (
   const struct GNUNET_TESTING_CommandHelperInit *msg)
 {
   uint16_t msize = ntohs (msg->header.size);
-  //uint32_t barrier_count = GNUNET_ntohll (msg->barrier_count);
+  // uint32_t barrier_count = GNUNET_ntohll (msg->barrier_count);
   uint32_t barrier_count = ntohl (msg->barrier_count);
   size_t bs = barrier_count * sizeof (struct GNUNET_ShortHashCode);
   size_t left = msize - bs - sizeof (*msg);
@@ -320,6 +335,14 @@ handle_helper_init (
     = (const struct GNUNET_ShortHashCode *) &msg[1];
   const char *topo = (const char *) &bd[barrier_count];
 
+  if (NULL != plugin)
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Double-init!\n");
+    global_ret = EXIT_FAILURE;
+    GNUNET_SCHEDULER_shutdown ();
+    return;
+  }
 
   GNUNET_assert ('\0' == topo[left - 1]);
   njt = GNUNET_TESTING_get_topo_from_string_ (topo);
@@ -347,13 +370,14 @@ handle_helper_init (
     GNUNET_SCHEDULER_shutdown ();
     return;
   }
-  struct GNUNET_TESTING_Command *commands = plugin->cls;
-  unsigned int i;
+  {
+    struct GNUNET_TESTING_Command *commands = plugin->cls;
 
-  for (i = 0; NULL != commands[i].run; i++)
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-              "helper %s\n",
-              commands[i].label.value);
+    for (unsigned int i = 0; NULL != commands[i].run; i++)
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "helper %s\n",
+                  commands[i].label.value);
+  }
   is = plugin->start_testcase (plugin->cls,
                                topo,
                                barrier_count,
