@@ -541,6 +541,8 @@ GNUNET_DNSPARSER_parse_uri (const char *udp_payload,
   struct GNUNET_DNSPARSER_UriRecord *uri;
   struct GNUNET_TUN_DnsUriRecord uri_bin;
   size_t old_off;
+  int max_len;
+  int len;
 
   old_off = *off;
   if (*off + sizeof(struct GNUNET_TUN_DnsUriRecord) > udp_payload_length)
@@ -552,8 +554,8 @@ GNUNET_DNSPARSER_parse_uri (const char *udp_payload,
   uri = GNUNET_new (struct GNUNET_DNSPARSER_UriRecord);
   uri->priority = ntohs (uri_bin.prio);
   uri->weight = ntohs (uri_bin.weight);
-  int max_len = udp_payload_length - sizeof(struct GNUNET_TUN_DnsUriRecord);
-  int len =  GNUNET_asprintf (&(uri->target), "%.*s", max_len,
+  max_len = udp_payload_length - sizeof(struct GNUNET_TUN_DnsUriRecord);
+  len =  GNUNET_asprintf (&(uri->target), "%.*s", max_len,
                               &udp_payload[*off]);
   (*off) += len;
   if (NULL == uri->target)
