@@ -33,7 +33,6 @@
 
 #if HAVE_MALLINFO2
 #include <malloc.h>
-#include "gauger.h"
 #endif
 
 
@@ -1557,7 +1556,10 @@ setup_service (struct GNUNET_SERVICE_Handle *sh)
 
     num = get_server_addresses (sh->service_name, sh->cfg, &addrs, &addrlens);
     if (GNUNET_SYSERR == num)
+    {
+      GNUNET_free (csocks);
       return GNUNET_SYSERR;
+    }
 
     for (int i = 0; i < num; i++)
     {
@@ -2147,31 +2149,6 @@ shutdown:
       LOG_STRERROR (GNUNET_ERROR_TYPE_WARNING, "write");
     GNUNET_break (0 == close (sh.ready_confirm_fd));
   }
-#if HAVE_MALLINFO2
-  {
-    char *counter;
-
-    if ( (GNUNET_YES ==
-          GNUNET_CONFIGURATION_have_value (sh.cfg,
-                                           service_name,
-                                           "GAUGER_HEAP")) &&
-         (GNUNET_OK ==
-          GNUNET_CONFIGURATION_get_value_string (sh.cfg,
-                                                 service_name,
-                                                 "GAUGER_HEAP",
-                                                 &counter)))
-    {
-      struct mallinfo2 mi;
-
-      mi = mallinfo2 ();
-      GAUGER (service_name,
-              counter,
-              mi.usmblks,
-              "blocks");
-      GNUNET_free (counter);
-    }
-  }
-#endif
   teardown_service (&sh);
   GNUNET_free (sh.handlers);
   GNUNET_SPEEDUP_stop_ ();
