@@ -1569,11 +1569,14 @@ GNUNET_SERVICE_MAIN ("nse",
 #if defined(__linux__) && defined(__GLIBC__)
 #include <malloc.h>
 
+void __attribute__ ((constructor))
+GNUNET_NSE_memory_init (void);
+
 /**
  * MINIMIZE heap size (way below 128k) since this process doesn't need much.
  */
 void __attribute__ ((constructor))
-GNUNET_NSE_memory_init ()
+GNUNET_NSE_memory_init (void)
 {
   mallopt (M_TRIM_THRESHOLD, 4 * 1024);
   mallopt (M_TOP_PAD, 1 * 1024);
