@@ -38,6 +38,8 @@
 #include "gnunet_rest_plugin.h"
 #include "gnunet_signatures.h"
 #include "json_reclaim.h"
+#include "reclaim_plugin.h"
+
 /**
  * REST root namespace
  */
@@ -884,66 +886,66 @@ add_attribute_cont (struct GNUNET_REST_RequestHandle *con_handle,
  *
  * @return a GNUNET_RECLAIM_Attribute, containing the new value
  */
-struct GNUNET_RECLAIM_Attribute *
-parse_jwt (const struct GNUNET_RECLAIM_Credential *cred,
-           const char *claim)
-{
-  char *jwt_string;
-  struct GNUNET_RECLAIM_Attribute *attr;
-  char delim[] = ".";
-  const char *type_str = NULL;
-  const char *val_str = NULL;
-  char *data;
-  size_t data_size;
-  uint32_t type;
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Parsing JWT attributes.\n");
-  char *decoded_jwt;
-  json_t *json_val;
-  json_error_t *json_err = NULL;
-
-  jwt_string = GNUNET_RECLAIM_credential_value_to_string (cred->type,
-                                                          cred->data,
-                                                          cred->data_size);
-  char *jwt_body = strtok (jwt_string, delim);
-  jwt_body = strtok (NULL, delim);
-  GNUNET_STRINGS_base64_decode (jwt_body, strlen (jwt_body),
-                                (void **) &decoded_jwt);
-  json_val = json_loads (decoded_jwt, JSON_DECODE_ANY, json_err);
-  const char *key;
-  json_t *value;
-  json_object_foreach (json_val, key, value) {
-    if (0 == strcasecmp (key,claim))
-    {
-      val_str = json_dumps (value, JSON_ENCODE_ANY);
-    }
-  }
-  type_str = "String";
-  type = GNUNET_RECLAIM_attribute_typename_to_number (type_str);
-  if (GNUNET_SYSERR == GNUNET_RECLAIM_attribute_string_to_value (type,val_str,
-                                                                 (void **) &data
-                                                                 ,
-                                                                 &data_size))
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                "Attribute value from JWT Parser invalid!\n");
-    GNUNET_RECLAIM_attribute_string_to_value (type,
-                                              "Error: Referenced Claim Name not Found",
-                                              (void **) &data,
-                                              &data_size);
-    attr = GNUNET_RECLAIM_attribute_new (claim, &cred->id,
-                                         type, data, data_size);
-    attr->id = cred->id;
-    attr->flag = 1;
-  }
-  else
-  {
-    attr = GNUNET_RECLAIM_attribute_new (claim, &cred->id,
-                                         type, data, data_size);
-    attr->id = cred->id;
-    attr->flag = 1;
-  }
-  return attr;
-}
+//static struct GNUNET_RECLAIM_Attribute *
+//parse_jwt (const struct GNUNET_RECLAIM_Credential *cred,
+//           const char *claim)
+//{
+//  char *jwt_string;
+//  struct GNUNET_RECLAIM_Attribute *attr;
+//  char delim[] = ".";
+//  const char *type_str = NULL;
+//  const char *val_str = NULL;
+//  char *data;
+//  size_t data_size;
+//  uint32_t type;
+//  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Parsing JWT attributes.\n");
+//  char *decoded_jwt;
+//  json_t *json_val;
+//  json_error_t *json_err = NULL;
+//
+//  jwt_string = GNUNET_RECLAIM_credential_value_to_string (cred->type,
+//                                                          cred->data,
+//                                                          cred->data_size);
+//  char *jwt_body = strtok (jwt_string, delim);
+//  jwt_body = strtok (NULL, delim);
+//  GNUNET_STRINGS_base64_decode (jwt_body, strlen (jwt_body),
+//                                (void **) &decoded_jwt);
+//  json_val = json_loads (decoded_jwt, JSON_DECODE_ANY, json_err);
+//  const char *key;
+//  json_t *value;
+//  json_object_foreach (json_val, key, value) {
+//    if (0 == strcasecmp (key,claim))
+//    {
+//      val_str = json_dumps (value, JSON_ENCODE_ANY);
+//    }
+//  }
+//  type_str = "String";
+//  type = GNUNET_RECLAIM_attribute_typename_to_number (type_str);
+//  if (GNUNET_SYSERR == GNUNET_RECLAIM_attribute_string_to_value (type,val_str,
+//                                                                 (void **) &data
+//                                                                 ,
+//                                                                 &data_size))
+//  {
+//    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+//                "Attribute value from JWT Parser invalid!\n");
+//    GNUNET_RECLAIM_attribute_string_to_value (type,
+//                                              "Error: Referenced Claim Name not Found",
+//                                              (void **) &data,
+//                                              &data_size);
+//    attr = GNUNET_RECLAIM_attribute_new (claim, &cred->id,
+//                                         type, data, data_size);
+//    attr->id = cred->id;
+//    attr->flag = 1;
+//  }
+//  else
+//  {
+//    attr = GNUNET_RECLAIM_attribute_new (claim, &cred->id,
+//                                         type, data, data_size);
+//    attr->id = cred->id;
+//    attr->flag = 1;
+//  }
+//  return attr;
+//}
 
 
 /**
@@ -1467,7 +1469,7 @@ REST_reclaim_process_request (void *plugin,
  * @return NULL on error, otherwise the plugin context
  */
 void *
-REST_reclaim_init (struct GNUNET_CONFIGURATION_Handle *c)
+REST_reclaim_init (const struct GNUNET_CONFIGURATION_Handle *c)
 {
   static struct Plugin plugin;
   struct GNUNET_REST_Plugin *api;
@@ -1502,7 +1504,7 @@ REST_reclaim_init (struct GNUNET_CONFIGURATION_Handle *c)
  * @param cls the plugin context (as returned by "init")
  * @return always NULL
  */
-void *
+void
 REST_reclaim_done (struct GNUNET_REST_Plugin *api)
 {
   struct Plugin *plugin = api->cls;
@@ -1530,7 +1532,6 @@ REST_reclaim_done (struct GNUNET_REST_Plugin *api)
   GNUNET_free (api);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Identity Provider REST plugin is finished\n");
-  return NULL;
 }
 
 
