@@ -1082,9 +1082,6 @@ main (int argc, char *const *argv)
   };
   int ret;
 
-  if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
-    return 2;
-
   ret = (GNUNET_OK == GNUNET_PROGRAM_run (argc,
                                           argv,
                                           "gnunet-daemon-topology",
@@ -1094,7 +1091,6 @@ main (int argc, char *const *argv)
                                           NULL))
         ? 0
         : 1;
-  GNUNET_free_nz ((void *) argv);
   return ret;
 }
 
