@@ -271,6 +271,11 @@ struct GNUNET_TRANSPORT_CommunicatorAvailableMessage
    */
   uint32_t cc;
 
+  /**
+   * The communicator can do burst msgs.
+   */
+  uint32_t can_burst;
+
   /* Followed by the address prefix of the communicator */
 };
 
@@ -668,6 +673,33 @@ struct GNUNET_TRANSPORT_CommunicatorBackchannelIncoming
      message to the communicator */
 };
 
+/**
+ * Message from transport to communicator to start a burst.
+ */
+struct GNUNET_TRANSPORT_StartBurst
+{
+  /**
+   * Type will be #GNUNET_MESSAGE_TYPE_TRANSPORT_START_BURST.
+   */
+  struct GNUNET_MessageHeader header;
+
+  /**
+   * Target peer.
+   */
+  struct GNUNET_PeerIdentity pid;
+
+  struct GNUNET_TIME_RelativeNBO rtt;
+
+  /* followed by UTF-8 encoded, 0-terminated human-readable address */
+};
+
+struct GNUNET_TRANSPORT_BurstFinished
+{
+  /**
+   * Type will be #GNUNET_MESSAGE_TYPE_TRANSPORT_BURST_FINISHED.
+   */
+  struct GNUNET_MessageHeader header;
+};
 
 /**
  * Request to start monitoring.
